==> ejc-metadata-api-3.0.0-20200421.061610-4-sources.jar: com/ejianc/foundation/metadata/vo/MdReferVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

import cn.hutool.json.JSONObject;

public class MdReferVO implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private String projectName;		//工程名称
	
	private Long projectId;			//工程id
	
	private String databaseName; //工程对应数据库名称

	private String entityName; // 实体名称

	private String entityFullName; // 实体全名

	private String tableName; // 表名称
	
	private List<JSONObject> refMapList; //参照映射字段

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getDatabaseName() {
		return databaseName;
	}

	public void setDatabaseName(String databaseName) {
		this.databaseName = databaseName;
	}

	public String getEntityName() {
		return entityName;
	}

	public void setEntityName(String entityName) {
		this.entityName = entityName;
	}

	public String getEntityFullName() {
		return entityFullName;
	}

	public void setEntityFullName(String entityFullName) {
		this.entityFullName = entityFullName;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public List<JSONObject> getRefMapList() {
		return refMapList;
	}

	public void setRefMapList(List<JSONObject> refMapList) {
		this.refMapList = refMapList;
	}
	
	
}

==> ejc-metadata-api-3.0.0-20200510.114340-16-sources.jar: com/ejianc/foundation/metadata/vo/MdReferVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

import cn.hutool.json.JSONObject;

public class MdReferVO implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private String projectName;		//工程名称
	
	private Long projectId;			//工程id
	
	private String databaseName; //工程对应数据库名称

	private String entityName; // 实体名称

	private String entityFullName; // 实体全名

	private String tableName; // 表名称
	
	private Map<String,String> refMapList; //参照映射字段

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getDatabaseName() {
		return databaseName;
	}

	public void setDatabaseName(String databaseName) {
		this.databaseName = databaseName;
	}

	public String getEntityName() {
		return entityName;
	}

	public void setEntityName(String entityName) {
		this.entityName = entityName;
	}

	public String getEntityFullName() {
		return entityFullName;
	}

	public void setEntityFullName(String entityFullName) {
		this.entityFullName = entityFullName;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public Map<String,String> getRefMapList() {
		return refMapList;
	}

	public void setRefMapList(Map<String,String> refMapList) {
		this.refMapList = refMapList;
	}
	
	
}
